==> 1.0.0.zip: terraform-provider-dynamix/wiki/1.0.0/04.05-Сборка-terraform-провайдера-в-образ.md <==
Образ приложения - современный способ запуска приложений. Образ приложения представляет собой контейнер, в который входит ОС и необходимые для работы приложения пакеты.  
Способов создать образ приложения довольно много, для этого существуют программы контейнеризации:
- Docker
- Podman
- и другие
Образ представляет собой "зафиксированную" версию приложения, что означает, что никакие изменения в приложения внесены быть не могут. Так же означает то, что приложение не может создавать побочные файлы при работе.  
Контейнер - это запущенный экземпляр образа. То есть, один образ может порождать множество контейнеров, каждый из которых будет включать в себя отдельный экземпляр приложения.
Одно из преимуществ работы приложения в контейнере - кроссплатформенность. Это преимущество обуславливается тем, что образ приложения уже включает в себя все необходимое для успешной работы приложения, в том числе операционную систему. Поэтому, пользователю достаточно установить на вычислительной машине программу, которая обеспечивает работу с образами приложений.

## Docker
Docker является одной из самых популярных программ для работы с образами.  
Docker позволяет:
- Создавать образы
- Запускать контейнеры
- Управлять контейнерами
- Управлять образами
Скачать и установить Docker можно по ссылке https://docs.docker.com/get-docker/

## Сборка terraform провайдера
### Требования:
- Docker
- git
- Компилятор языка GO
= make
### Установка необходимых программ
1. Компилятор языка GO можно скачать и установить по ссылке: https://go.dev/dl/
2. Docker можно скачать и установить по ссылке выше.
3. Git можно скачать и установить по ссылке: https://git-scm.com/
4. Программа make входит в пакет установленных программ для ОС Linux. Для Windows можно воспользоваться инструкцией со stack overflow: https://stackoverflow.com/questions/32127524/how-to-install-and-use-make-in-windows
### Порядок действий
1. Склонировать репозиторий с провайдером:
```bash
git clone https://github.com/rudecs/terraform-provider-dynamix.git
```
2. Перейти в директорию со скачанным кодом:
```bash
cd terraform-provider-dynamix
```
3. Выполнить команду:
```bash
make image
```
В результате выполнения данной последовательности, будет создан docker образ, который содержит в себе приложение terraform, terraform провайдер.

==> 1.2.1.zip: terraform-provider-dynamix/wiki/1.1.0/04.05-Сборка-terraform-провайдера-в-образ.md <==
Образ приложения - современный способ запуска приложений. Образ приложения представляет собой контейнер, в который входит ОС и необходимые для работы приложения пакеты.  
Способов создать образ приложения довольно много, для этого существуют программы контейнеризации:
- Docker
- Podman
- и другие
Образ представляет собой "зафиксированную" версию приложения, что означает, что никакие изменения в приложения внесены быть не могут. Так же означает то, что приложение не может создавать побочные файлы при работе.  
Контейнер - это запущенный экземпляр образа. То есть, один образ может порождать множество контейнеров, каждый из которых будет включать в себя отдельный экземпляр приложения.
Одно из преимуществ работы приложения в контейнере - кроссплатформенность. Это преимущество обуславливается тем, что образ приложения уже включает в себя все необходимое для успешной работы приложения, в том числе операционную систему. Поэтому, пользователю достаточно установить на вычислительной машине программу, которая обеспечивает работу с образами приложений.

## Docker
Docker является одной из самых популярных программ для работы с образами.  
Docker позволяет:
- Создавать образы
- Запускать контейнеры
- Управлять контейнерами
- Управлять образами
Скачать и установить Docker можно по ссылке https://docs.docker.com/get-docker/

## Сборка terraform провайдера
### Требования:
- Docker
- git
- Компилятор языка GO
= make
### Установка необходимых программ
1. Компилятор языка GO можно скачать и установить по ссылке: https://go.dev/dl/
2. Docker можно скачать и установить по ссылке выше.
3. Git можно скачать и установить по ссылке: https://git-scm.com/
4. Программа make входит в пакет установленных программ для ОС Linux. Для Windows можно воспользоваться инструкцией со stack overflow: https://stackoverflow.com/questions/32127524/how-to-install-and-use-make-in-windows
### Порядок действий
1. Склонировать репозиторий с провайдером:
```bash
git clone https://repository.basistech.ru/BASIS/terraform-provider-dynamix
```
2. Перейти в директорию со скачанным кодом:
```bash
cd terraform-provider-dynamix
```
3. Выполнить команду:
```bash
make image
```
В результате выполнения данной последовательности, будет создан docker образ, который содержит в себе приложение terraform, terraform провайдер.
